# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RelatedReportResponse(Model):
    """RelatedReportResponse.

    :param specific_report_id: Specific report id of the related report
    :type specific_report_id: int
    :param name: Name of the related report
    :type name: str
    :param description: Description of the related report
    :type description: str
    :param report_source: The rendering engine used for the report (EnergyCAP
     currently uses SSRS and Crystal)
    :type report_source: str
    """

    _attribute_map = {
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'report_source': {'key': 'reportSource', 'type': 'str'},
    }

    def __init__(self, *, specific_report_id: int=None, name: str=None, description: str=None, report_source: str=None, **kwargs) -> None:
        super(RelatedReportResponse, self).__init__(**kwargs)
        self.specific_report_id = specific_report_id
        self.name = name
        self.description = description
        self.report_source = report_source
