# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAccrualExclusionRequest(Model):
    """BillAccrualExclusionRequest.

    All required parameters must be populated in order to send to Azure.

    :param bill_ids: Required. List of bill IDs to exclude from accruals or
     include again <span class='property-internal'>Required</span>
    :type bill_ids: list[int]
    :param exclude: Required. Whether or not the bill ids should be excluded
     from accruals, or included again <span
     class='property-internal'>Required</span>
    :type exclude: bool
    """

    _validation = {
        'bill_ids': {'required': True},
        'exclude': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'exclude': {'key': 'exclude', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillAccrualExclusionRequest, self).__init__(**kwargs)
        self.bill_ids = kwargs.get('bill_ids', None)
        self.exclude = kwargs.get('exclude', None)
