# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityMeterTypeMappingChild(Model):
    """EnergyStarCommodityMeterTypeMappingChild.

    :param pm_unit_code: The unit code in Portfolio Manager
    :type pm_unit_code: str
    :param is_delivery: When true, auto-created Portfolio Manager meters of
     this commodity are serviced "by delivery" rather than "by metering"
    :type is_delivery: bool
    :param suported_pm_commodities_with_default: List of supported Portfolio
     Manager commodities for this ECAP Commodity
     Every entry includes the commodity code and whether the commodity is the
     default for Portfolio Manager
    :type suported_pm_commodities_with_default:
     list[~energycap.sdk.models.PmCommodityChild]
    """

    _attribute_map = {
        'pm_unit_code': {'key': 'pmUnitCode', 'type': 'str'},
        'is_delivery': {'key': 'isDelivery', 'type': 'bool'},
        'suported_pm_commodities_with_default': {'key': 'suportedPmCommoditiesWithDefault', 'type': '[PmCommodityChild]'},
    }

    def __init__(self, *, pm_unit_code: str=None, is_delivery: bool=None, suported_pm_commodities_with_default=None, **kwargs) -> None:
        super(EnergyStarCommodityMeterTypeMappingChild, self).__init__(**kwargs)
        self.pm_unit_code = pm_unit_code
        self.is_delivery = is_delivery
        self.suported_pm_commodities_with_default = suported_pm_commodities_with_default
