# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeneralLedgerResponse(Model):
    """GeneralLedgerResponse.

    :param general_ledger_id: General Ledger Identifier
    :type general_ledger_id: int
    :param general_ledger_code: Unique code for the general ledger
    :type general_ledger_code: str
    :param sub_codes: List of 20 subCodes with their index, name, and value
    :type sub_codes: list[~energycap.sdk.models.GLSubCodeChild]
    """

    _attribute_map = {
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'sub_codes': {'key': 'subCodes', 'type': '[GLSubCodeChild]'},
    }

    def __init__(self, **kwargs):
        super(GeneralLedgerResponse, self).__init__(**kwargs)
        self.general_ledger_id = kwargs.get('general_ledger_id', None)
        self.general_ledger_code = kwargs.get('general_ledger_code', None)
        self.sub_codes = kwargs.get('sub_codes', None)
