# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionApprove(Model):
    """BillActionApprove.

    :param ids:  <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type ids: list[int]
    :param approve:  <span class='property-internal'>Required (defined)</span>
    :type approve: bool
    """

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
        'approve': {'key': 'approve', 'type': 'bool'},
    }

    def __init__(self, *, ids=None, approve: bool=None, **kwargs) -> None:
        super(BillActionApprove, self).__init__(**kwargs)
        self.ids = ids
        self.approve = approve
