# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class QuickReport(Model):
    """QuickReport.

    :param report_code: Report code of the report to execute
    :type report_code: str
    :param file_name: File name that the report file will receive
    :type file_name: str
    :param filters: The filters to apply to this execution of the report. They
     will not be saved, and stored filters will not be honored.
    :type filters: list[~energycap.sdk.models.QuickFilter]
    """

    _attribute_map = {
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'file_name': {'key': 'fileName', 'type': 'str'},
        'filters': {'key': 'filters', 'type': '[QuickFilter]'},
    }

    def __init__(self, *, report_code: str=None, file_name: str=None, filters=None, **kwargs) -> None:
        super(QuickReport, self).__init__(**kwargs)
        self.report_code = report_code
        self.file_name = file_name
        self.filters = filters
