# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OkResult(Model):
    """OkResult.

    :param status_code:
    :type status_code: int
    """

    _attribute_map = {
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self, *, status_code: int=None, **kwargs) -> None:
        super(OkResult, self).__init__(**kwargs)
        self.status_code = status_code
