# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Estimated(Model):
    """Estimated.

    All required parameters must be populated in order to send to Azure.

    :param column_number: Required. Column number specifying where to look for
     the estimated indicator <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 1 and 2147483647</span>
    :type column_number: int
    :param indicator: Required. The string used to indicate the reading is
     estimated
     If this value is found in the column number specified the reading will be
     marked as estimated
     Example: e, E, 1, 0, est, *, this is my estimated read <span
     class='property-internal'>Required</span>
    :type indicator: str
    """

    _validation = {
        'column_number': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'indicator': {'required': True},
    }

    _attribute_map = {
        'column_number': {'key': 'columnNumber', 'type': 'int'},
        'indicator': {'key': 'indicator', 'type': 'str'},
    }

    def __init__(self, *, column_number: int, indicator: str, **kwargs) -> None:
        super(Estimated, self).__init__(**kwargs)
        self.column_number = column_number
        self.indicator = indicator
