# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorRequest(Model):
    """VendorRequest.

    All required parameters must be populated in order to send to Azure.

    :param vendor_code: Required. The vendor code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type vendor_code: str
    :param vendor_info: Required. The vendor info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type vendor_info: str
    :param website: The vendor's website <span class='property-internal'>Must
     be between 0 and 255 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type website: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param vendor_description: A description of the vendor <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
     <span class='property-internal'>Required (defined)</span>. Default value:
     "Æ" .
    :type vendor_description: str
    """

    _validation = {
        'vendor_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'vendor_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'website': {'max_length': 255, 'min_length': 0},
        'vendor_description': {'max_length': 4000, 'min_length': 0},
    }

    _attribute_map = {
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'website': {'key': 'website', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'vendor_description': {'key': 'vendorDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(VendorRequest, self).__init__(**kwargs)
        self.vendor_code = kwargs.get('vendor_code', None)
        self.vendor_info = kwargs.get('vendor_info', None)
        self.website = kwargs.get('website', None)
        self.address = kwargs.get('address', None)
        self.vendor_description = kwargs.get('vendor_description', "Æ")
