# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationSummary(Model):
    """WeatherStationSummary.

    :param begin_date: Begin date for this weather station
     May differ from the begin date provided by the user if the most recent
     weather reading for this station was earlier.
    :type begin_date: datetime
    :param earliest_reading_date: Earliest reading date imported for this
     weather station
     May differ from the begin date provided by the user if the most recent
     weather reading available for this station was later.
    :type earliest_reading_date: datetime
    :param weather_station_id: Weather station ID
    :type weather_station_id: int
    :param weather_station_code: Weather station code
    :type weather_station_code: str
    :param weather_station_name: Weather station name
    :type weather_station_name: str
    :param base_weather_station_code: Source weather station code (if any)
    :type base_weather_station_code: str
    :param number_of_readings_imported: Number of readings imported
    :type number_of_readings_imported: int
    :param number_of_failed_readings: Number of readings failed to import
    :type number_of_failed_readings: int
    :param channel_id: Channel ID
    :type channel_id: int
    :param channel_code: Channel code
    :type channel_code: str
    :param channel_interval_in_seconds: Channel interval in seconds
    :type channel_interval_in_seconds: int
    """

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'earliest_reading_date': {'key': 'earliestReadingDate', 'type': 'iso-8601'},
        'weather_station_id': {'key': 'weatherStationId', 'type': 'int'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
        'weather_station_name': {'key': 'weatherStationName', 'type': 'str'},
        'base_weather_station_code': {'key': 'baseWeatherStationCode', 'type': 'str'},
        'number_of_readings_imported': {'key': 'numberOfReadingsImported', 'type': 'int'},
        'number_of_failed_readings': {'key': 'numberOfFailedReadings', 'type': 'int'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(WeatherStationSummary, self).__init__(**kwargs)
        self.begin_date = kwargs.get('begin_date', None)
        self.earliest_reading_date = kwargs.get('earliest_reading_date', None)
        self.weather_station_id = kwargs.get('weather_station_id', None)
        self.weather_station_code = kwargs.get('weather_station_code', None)
        self.weather_station_name = kwargs.get('weather_station_name', None)
        self.base_weather_station_code = kwargs.get('base_weather_station_code', None)
        self.number_of_readings_imported = kwargs.get('number_of_readings_imported', None)
        self.number_of_failed_readings = kwargs.get('number_of_failed_readings', None)
        self.channel_id = kwargs.get('channel_id', None)
        self.channel_code = kwargs.get('channel_code', None)
        self.channel_interval_in_seconds = kwargs.get('channel_interval_in_seconds', None)
