# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseGHGScope(Model):
    """PlaceDigestGHGYearlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param ghg_scope_type_code: GHG scope type code
    :type ghg_scope_type_code: str
    :param ghg_scope_type_info: GHG scope type code
    :type ghg_scope_type_info: str
    :param ghg_types: An array of ghg type yearly data
    :type ghg_types:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseGHGType]
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'ghg_scope_type_code': {'key': 'ghgScopeTypeCode', 'type': 'str'},
        'ghg_scope_type_info': {'key': 'ghgScopeTypeInfo', 'type': 'str'},
        'ghg_types': {'key': 'ghgTypes', 'type': '[PlaceDigestGHGYearlyResponseGHGType]'},
    }

    def __init__(self, *, ghg_scope_id: int=None, ghg_scope_code: str=None, ghg_scope_info: str=None, ghg_scope_type_code: str=None, ghg_scope_type_info: str=None, ghg_types=None, **kwargs) -> None:
        super(PlaceDigestGHGYearlyResponseGHGScope, self).__init__(**kwargs)
        self.ghg_scope_id = ghg_scope_id
        self.ghg_scope_code = ghg_scope_code
        self.ghg_scope_info = ghg_scope_info
        self.ghg_scope_type_code = ghg_scope_type_code
        self.ghg_scope_type_info = ghg_scope_type_info
        self.ghg_types = ghg_types
