# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityChild(Model):
    """CommodityChild.

    :param commodity_id: The commodity identifier <span
     class='property-internal'>Required (defined)</span>
    :type commodity_id: int
    :param commodity_code: The commodity code <span
     class='property-internal'>Required (defined)</span>
    :type commodity_code: str
    :param commodity_info: The commodity info <span
     class='property-internal'>Required (defined)</span>
    :type commodity_info: str
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(CommodityChild, self).__init__(**kwargs)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)
