# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyResponse(Model):
    """ApiKeyResponse.

    :param api_key_id: The identifier of the API key
    :type api_key_id: int
    :param api_key_name: The name of the API key
    :type api_key_name: str
    :param api_key_description: A description of the API key
    :type api_key_description: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The API key creation date
    :type created_date: datetime
    """

    _attribute_map = {
        'api_key_id': {'key': 'apiKeyId', 'type': 'int'},
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(ApiKeyResponse, self).__init__(**kwargs)
        self.api_key_id = kwargs.get('api_key_id', None)
        self.api_key_name = kwargs.get('api_key_name', None)
        self.api_key_description = kwargs.get('api_key_description', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_date = kwargs.get('created_date', None)
