# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowResponse(Model):
    """ChargebackWorkflowResponse.

    :param chargeback_workflow_steps: List of workflow steps with details
    :type chargeback_workflow_steps:
     list[~energycap.sdk.models.ChargebackWorkflowStep]
    :param chargeback_workflow_id: Identifier for the chargeback workflow
    :type chargeback_workflow_id: int
    :param chargeback_workflow_info: Name given to the chargeback workflow
    :type chargeback_workflow_info: str
    """

    _attribute_map = {
        'chargeback_workflow_steps': {'key': 'chargebackWorkflowSteps', 'type': '[ChargebackWorkflowStep]'},
        'chargeback_workflow_id': {'key': 'chargebackWorkflowId', 'type': 'int'},
        'chargeback_workflow_info': {'key': 'chargebackWorkflowInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ChargebackWorkflowResponse, self).__init__(**kwargs)
        self.chargeback_workflow_steps = kwargs.get('chargeback_workflow_steps', None)
        self.chargeback_workflow_id = kwargs.get('chargeback_workflow_id', None)
        self.chargeback_workflow_info = kwargs.get('chargeback_workflow_info', None)
