# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionLogResponse(Model):
    """ReportDistributionLogResponse.

    :param report_distribution_log_id: The report distribution log identifier
    :type report_distribution_log_id: int
    :param report_distribution:
    :type report_distribution: ~energycap.sdk.models.ReportDistributionChild
    :param begin_date: The date and time the report distribution was started
    :type begin_date: datetime
    :param end_date: The date and time the report distribution was completed
    :type end_date: datetime
    :param status: The status of the report distribution
     Possible values - In Progress, Complete, Not sent, Some reports not sent
    :type status: str
    :param number_of_recipients: The number of unique recipients for the
     report
     If a user is a member of multiple groups assigned to the report
     distribution they will only be counted once
    :type number_of_recipients: int
    """

    _attribute_map = {
        'report_distribution_log_id': {'key': 'reportDistributionLogId', 'type': 'int'},
        'report_distribution': {'key': 'reportDistribution', 'type': 'ReportDistributionChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'status': {'key': 'status', 'type': 'str'},
        'number_of_recipients': {'key': 'numberOfRecipients', 'type': 'int'},
    }

    def __init__(self, *, report_distribution_log_id: int=None, report_distribution=None, begin_date=None, end_date=None, status: str=None, number_of_recipients: int=None, **kwargs) -> None:
        super(ReportDistributionLogResponse, self).__init__(**kwargs)
        self.report_distribution_log_id = report_distribution_log_id
        self.report_distribution = report_distribution
        self.begin_date = begin_date
        self.end_date = end_date
        self.status = status
        self.number_of_recipients = number_of_recipients
