# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelChild(Model):
    """ChannelChild.

    :param channel_code: The channel code
     Combines
     observationTypeCode:unitCode:observationMethodCode:observationRuleCode:interval
     in minutes
    :type channel_code: str
    :param channel_id: The channel identifier
    :type channel_id: int
    :param interval: The channel interval in seconds.
     Monthly = 2592000
     Weekly = 604800
     Daily = 86400
     Hourly = 3600
     Thirty_Minutes = 1800
     Fifteen_Minutes = 900
    :type interval: int
    """

    _attribute_map = {
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ChannelChild, self).__init__(**kwargs)
        self.channel_code = kwargs.get('channel_code', None)
        self.channel_id = kwargs.get('channel_id', None)
        self.interval = kwargs.get('interval', None)
