# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillPaymentDetailsResponse(Model):
    """BillPaymentDetailsResponse.

    :param success: Number of successful bill payment detail updates <span
     class='property-internal'>Required (defined)</span>
    :type success: int
    :param failure: Number of unsuccessful bill payment detail updates <span
     class='property-internal'>Required (defined)</span>
    :type failure: int
    :param bill_payment_details_items: List of unsuccessful bill payment
     detail updates with reasons for failure <span
     class='property-internal'>Required (defined)</span>
    :type bill_payment_details_items:
     list[~energycap.sdk.models.BillPaymentDetailsItem]
    """

    _attribute_map = {
        'success': {'key': 'success', 'type': 'int'},
        'failure': {'key': 'failure', 'type': 'int'},
        'bill_payment_details_items': {'key': 'billPaymentDetailsItems', 'type': '[BillPaymentDetailsItem]'},
    }

    def __init__(self, **kwargs):
        super(BillPaymentDetailsResponse, self).__init__(**kwargs)
        self.success = kwargs.get('success', None)
        self.failure = kwargs.get('failure', None)
        self.bill_payment_details_items = kwargs.get('bill_payment_details_items', None)
