# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandResponse(Model):
    """CalculatedBillDemandResponse.

    :param readings_from_channel:
    :type readings_from_channel:
     ~energycap.sdk.models.ChannelChildWithObservationType
    :param fixed_demand:
    :type fixed_demand: ~energycap.sdk.models.FixedAmountResponse
    """

    _attribute_map = {
        'readings_from_channel': {'key': 'readingsFromChannel', 'type': 'ChannelChildWithObservationType'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedAmountResponse'},
    }

    def __init__(self, **kwargs):
        super(CalculatedBillDemandResponse, self).__init__(**kwargs)
        self.readings_from_channel = kwargs.get('readings_from_channel', None)
        self.fixed_demand = kwargs.get('fixed_demand', None)
