# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseGHGType(Model):
    """PlaceDigestGHGYearlyResponseGHGType.

    :param ghg_type_id: GHG type identifier
    :type ghg_type_id: int
    :param ghg_type_code: GHG type code
    :type ghg_type_code: str
    :param ghg_type_info: GHG type info
    :type ghg_type_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGYearlyResponseTargetComparison
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseResults]
    """

    _attribute_map = {
        'ghg_type_id': {'key': 'ghgTypeId', 'type': 'int'},
        'ghg_type_code': {'key': 'ghgTypeCode', 'type': 'str'},
        'ghg_type_info': {'key': 'ghgTypeInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGYearlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGYearlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestGHGYearlyResponseGHGType, self).__init__(**kwargs)
        self.ghg_type_id = kwargs.get('ghg_type_id', None)
        self.ghg_type_code = kwargs.get('ghg_type_code', None)
        self.ghg_type_info = kwargs.get('ghg_type_info', None)
        self.target_comparison = kwargs.get('target_comparison', None)
        self.results = kwargs.get('results', None)
