# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmailProperties(Model):
    """EmailProperties.

    All required parameters must be populated in order to send to Azure.

    :param subject: Required.  <span class='property-internal'>Required</span>
    :type subject: str
    :param body:
    :type body: str
    :param recipients:  <span class='property-internal'>Cannot be Empty</span>
    :type recipients: list[str]
    """

    _validation = {
        'subject': {'required': True},
    }

    _attribute_map = {
        'subject': {'key': 'subject', 'type': 'str'},
        'body': {'key': 'body', 'type': 'str'},
        'recipients': {'key': 'recipients', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(EmailProperties, self).__init__(**kwargs)
        self.subject = kwargs.get('subject', None)
        self.body = kwargs.get('body', None)
        self.recipients = kwargs.get('recipients', None)
