# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountCodeHistoryChild(Model):
    """AccountCodeHistoryChild.

    :param previous_account_code: The previous account code of this account
    :type previous_account_code: str
    :param end_date: Date that the account code was changed
    :type end_date: datetime
    """

    _attribute_map = {
        'previous_account_code': {'key': 'previousAccountCode', 'type': 'str'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, previous_account_code: str=None, end_date=None, **kwargs) -> None:
        super(AccountCodeHistoryChild, self).__init__(**kwargs)
        self.previous_account_code = previous_account_code
        self.end_date = end_date
