# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationResponse(Model):
    """NotificationResponse.

    :param message_preview: The notification message with any html tags
     stripped out
    :type message_preview: str
    :param notification_id: The id of the notification
    :type notification_id: long
    :param read: True if the notification has been read
    :type read: bool
    :param archived: True if the notification has been archived
    :type archived: bool
    :param subject: Subject of the notification
    :type subject: str
    :param created_date: The date and time the notification was generated
    :type created_date: datetime
    :param notification_type:
    :type notification_type: ~energycap.sdk.models.NotificationType
    """

    _attribute_map = {
        'message_preview': {'key': 'messagePreview', 'type': 'str'},
        'notification_id': {'key': 'notificationId', 'type': 'long'},
        'read': {'key': 'read', 'type': 'bool'},
        'archived': {'key': 'archived', 'type': 'bool'},
        'subject': {'key': 'subject', 'type': 'str'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'notification_type': {'key': 'notificationType', 'type': 'NotificationType'},
    }

    def __init__(self, *, message_preview: str=None, notification_id: int=None, read: bool=None, archived: bool=None, subject: str=None, created_date=None, notification_type=None, **kwargs) -> None:
        super(NotificationResponse, self).__init__(**kwargs)
        self.message_preview = message_preview
        self.notification_id = notification_id
        self.read = read
        self.archived = archived
        self.subject = subject
        self.created_date = created_date
        self.notification_type = notification_type
