# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WorkflowDisplaySetting(Model):
    """WorkflowDisplaySetting.

    :param show_unapproved_list: Indicates whether or not to show the
     Unapproved bill list in Bill Processing
    :type show_unapproved_list: bool
    :param show_ap_export_list: Indicates whether or not to show the Waiting
     for Export to AP bill list in Bill Processing
    :type show_ap_export_list: bool
    :param show_gl_export_list: Indicates whether or not to show the Waiting
     for Export to GL bill list in Bill Processing
    :type show_gl_export_list: bool
    :param show_export_hold_list: Indicates whether or not to show the Held
     from Export bill list in Bill Processing
    :type show_export_hold_list: bool
    """

    _attribute_map = {
        'show_unapproved_list': {'key': 'showUnapprovedList', 'type': 'bool'},
        'show_ap_export_list': {'key': 'showAPExportList', 'type': 'bool'},
        'show_gl_export_list': {'key': 'showGLExportList', 'type': 'bool'},
        'show_export_hold_list': {'key': 'showExportHoldList', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(WorkflowDisplaySetting, self).__init__(**kwargs)
        self.show_unapproved_list = kwargs.get('show_unapproved_list', None)
        self.show_ap_export_list = kwargs.get('show_ap_export_list', None)
        self.show_gl_export_list = kwargs.get('show_gl_export_list', None)
        self.show_export_hold_list = kwargs.get('show_export_hold_list', None)
