# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationSettingResponse(Model):
    """NotificationSettingResponse.

    :param notification_type:
    :type notification_type: ~energycap.sdk.models.NotificationType
    :param configured_notification_option: The currently configured
     notification option
    :type configured_notification_option: str
    :param available_notification_options: All possible notification options
     for this setting
    :type available_notification_options: list[str]
    """

    _attribute_map = {
        'notification_type': {'key': 'notificationType', 'type': 'NotificationType'},
        'configured_notification_option': {'key': 'configuredNotificationOption', 'type': 'str'},
        'available_notification_options': {'key': 'availableNotificationOptions', 'type': '[str]'},
    }

    def __init__(self, *, notification_type=None, configured_notification_option: str=None, available_notification_options=None, **kwargs) -> None:
        super(NotificationSettingResponse, self).__init__(**kwargs)
        self.notification_type = notification_type
        self.configured_notification_option = configured_notification_option
        self.available_notification_options = available_notification_options
