# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationChild(Model):
    """WeatherStationChild.

    :param station_id: Weather Station Id
    :type station_id: int
    :param station_code: Weather Station Code
    :type station_code: str
    :param station_info: Weather Station Name
    :type station_info: str
    :param city: City the weather station is located
    :type city: str
    :param state: State the weather station is located
    :type state: str
    :param country: Country the weather station is located
    :type country: str
    """

    _attribute_map = {
        'station_id': {'key': 'stationId', 'type': 'int'},
        'station_code': {'key': 'stationCode', 'type': 'str'},
        'station_info': {'key': 'stationInfo', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WeatherStationChild, self).__init__(**kwargs)
        self.station_id = kwargs.get('station_id', None)
        self.station_code = kwargs.get('station_code', None)
        self.station_info = kwargs.get('station_info', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
