# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessRelease(Model):
    """DataAccessRelease.

    :param data_access_release_id: Data Access Release Identifier
    :type data_access_release_id: int
    :param meta_data:
    :type meta_data: ~energycap.sdk.models.DataAccessReleaseMetaData
    :param release_form: File name of the uploaded release form
     This is only saved on a manual data release request
     Null when request was completed by email
    :type release_form: str
    :param submitted_date: Date and time the data release request was
     submitted
    :type submitted_date: datetime
    :param submitted_by: Email address of the person who completed the request
    :type submitted_by: str
    """

    _attribute_map = {
        'data_access_release_id': {'key': 'dataAccessReleaseId', 'type': 'int'},
        'meta_data': {'key': 'metaData', 'type': 'DataAccessReleaseMetaData'},
        'release_form': {'key': 'releaseForm', 'type': 'str'},
        'submitted_date': {'key': 'submittedDate', 'type': 'iso-8601'},
        'submitted_by': {'key': 'submittedBy', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataAccessRelease, self).__init__(**kwargs)
        self.data_access_release_id = kwargs.get('data_access_release_id', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.release_form = kwargs.get('release_form', None)
        self.submitted_date = kwargs.get('submitted_date', None)
        self.submitted_by = kwargs.get('submitted_by', None)
