# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyEditRequest(Model):
    """ApiKeyEditRequest.

    All required parameters must be populated in order to send to Azure.

    :param api_key_name: Required. The name of the API key <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 60 characters</span>
    :type api_key_name: str
    :param api_key_description: A description for the API key <span
     class='property-internal'>Required (defined)</span>
    :type api_key_description: str
    """

    _validation = {
        'api_key_name': {'required': True, 'max_length': 60, 'min_length': 0},
    }

    _attribute_map = {
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
    }

    def __init__(self, *, api_key_name: str, api_key_description: str=None, **kwargs) -> None:
        super(ApiKeyEditRequest, self).__init__(**kwargs)
        self.api_key_name = api_key_name
        self.api_key_description = api_key_description
