# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StatisticsResponse(Model):
    """StatisticsResponse.

    :param model: The model value
    :type model: float
    :param difference: The difference between the model and the actual value
    :type difference: float
    :param standard_deviation: Statistical measure of how spread out numbers
     are from the average
    :type standard_deviation: float
    :param variance: Statistical measure of how far each value in the data set
     is from the mean
    :type variance: float
    :param r_squared: Statistical measure of how close the data is to the
     fitted regression line
    :type r_squared: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    :param severity:
    :type severity: ~energycap.sdk.models.OutlierSeverityChild
    """

    _attribute_map = {
        'model': {'key': 'model', 'type': 'float'},
        'difference': {'key': 'difference', 'type': 'float'},
        'standard_deviation': {'key': 'standardDeviation', 'type': 'float'},
        'variance': {'key': 'variance', 'type': 'float'},
        'r_squared': {'key': 'rSquared', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'severity': {'key': 'severity', 'type': 'OutlierSeverityChild'},
    }

    def __init__(self, **kwargs):
        super(StatisticsResponse, self).__init__(**kwargs)
        self.model = kwargs.get('model', None)
        self.difference = kwargs.get('difference', None)
        self.standard_deviation = kwargs.get('standard_deviation', None)
        self.variance = kwargs.get('variance', None)
        self.r_squared = kwargs.get('r_squared', None)
        self.unit = kwargs.get('unit', None)
        self.severity = kwargs.get('severity', None)
