# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseState(Model):
    """DataAccessReleaseState.

    :param submitted_date: The date that the data access release was
     submitted.
     Null if there is not a release yet.
    :type submitted_date: datetime
    :param release_status:
    :type release_status: ~energycap.sdk.models.DataAccessReleaseStatus
    """

    _attribute_map = {
        'submitted_date': {'key': 'submittedDate', 'type': 'iso-8601'},
        'release_status': {'key': 'releaseStatus', 'type': 'DataAccessReleaseStatus'},
    }

    def __init__(self, *, submitted_date=None, release_status=None, **kwargs) -> None:
        super(DataAccessReleaseState, self).__init__(**kwargs)
        self.submitted_date = submitted_date
        self.release_status = release_status
