# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSubmissionRequest(Model):
    """NOTE: this class also serves as a representation of
    EnergyStarTask.settings.

    All required parameters must be populated in order to send to Azure.

    :param places: Required. List of places/submission periods to include in
     ENERGY STAR submission <span class='property-internal'>Required</span>
     <span class='property-internal'>Cannot be Empty</span>
    :type places: list[~energycap.sdk.models.EnergyStarSubmissionPlaceChild]
    """

    _validation = {
        'places': {'required': True},
    }

    _attribute_map = {
        'places': {'key': 'places', 'type': '[EnergyStarSubmissionPlaceChild]'},
    }

    def __init__(self, *, places, **kwargs) -> None:
        super(EnergyStarSubmissionRequest, self).__init__(**kwargs)
        self.places = places
