# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupPlaceGroupMember(Model):
    """GroupPlaceGroupMember.

    :param place_id: The place identifier <span
     class='property-internal'>Required (defined)</span>
    :type place_id: int
    :param place_code: The place code <span class='property-internal'>Required
     (defined)</span>
    :type place_code: str
    :param place_info: The place info <span class='property-internal'>Required
     (defined)</span>
    :type place_info: str
    :param parent:
    :type parent: ~energycap.sdk.models.PlaceChild
    :param place_type:
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    :param include_in_charts: The flag determining whether the place is
     included in group charts <span class='property-internal'>Required
     (defined)</span>
    :type include_in_charts: bool
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'parent': {'key': 'parent', 'type': 'PlaceChild'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, *, place_id: int=None, place_code: str=None, place_info: str=None, parent=None, place_type=None, include_in_charts: bool=None, **kwargs) -> None:
        super(GroupPlaceGroupMember, self).__init__(**kwargs)
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.parent = parent
        self.place_type = place_type
        self.include_in_charts = include_in_charts
