# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListResponseListItem(Model):
    """ListResponseListItem.

    :param field_id:
    :type field_id: int
    :param name:
    :type name: str
    :param value:
    :type value: object
    """

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, *, field_id: int=None, name: str=None, value=None, **kwargs) -> None:
        super(ListResponseListItem, self).__init__(**kwargs)
        self.field_id = field_id
        self.name = name
        self.value = value
