# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillDeleteActionResult(Model):
    """BillDeleteActionResult.

    :param selected:
    :type selected: int
    :param deleted:
    :type deleted: int
    """

    _attribute_map = {
        'selected': {'key': 'selected', 'type': 'int'},
        'deleted': {'key': 'deleted', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(BillDeleteActionResult, self).__init__(**kwargs)
        self.selected = kwargs.get('selected', None)
        self.deleted = kwargs.get('deleted', None)
