# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseMetaData(Model):
    """DataAccessReleaseMetaData.

    :param account_number:
    :type account_number: str
    :param name_on_bill:
    :type name_on_bill: str
    :param service_address:
    :type service_address: str
    """

    _attribute_map = {
        'account_number': {'key': 'accountNumber', 'type': 'str'},
        'name_on_bill': {'key': 'nameOnBill', 'type': 'str'},
        'service_address': {'key': 'serviceAddress', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataAccessReleaseMetaData, self).__init__(**kwargs)
        self.account_number = kwargs.get('account_number', None)
        self.name_on_bill = kwargs.get('name_on_bill', None)
        self.service_address = kwargs.get('service_address', None)
