# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DeleteReadingResponse(Model):
    """DeleteReadingResponse.

    :param deleted: The number of readings deleted
    :type deleted: int
    :param failures: Data representing the failed reading deletion
    :type failures: list[~energycap.sdk.models.ReadingDelete]
    """

    _attribute_map = {
        'deleted': {'key': 'deleted', 'type': 'int'},
        'failures': {'key': 'failures', 'type': '[ReadingDelete]'},
    }

    def __init__(self, **kwargs):
        super(DeleteReadingResponse, self).__init__(**kwargs)
        self.deleted = kwargs.get('deleted', None)
        self.failures = kwargs.get('failures', None)
