# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LoginResponse(Model):
    """LoginResponse.

    :param token:
    :type token: str
    :param user:
    :type user: ~energycap.sdk.models.ApiUser
    """

    _attribute_map = {
        'token': {'key': 'token', 'type': 'str'},
        'user': {'key': 'user', 'type': 'ApiUser'},
    }

    def __init__(self, *, token: str=None, user=None, **kwargs) -> None:
        super(LoginResponse, self).__init__(**kwargs)
        self.token = token
        self.user = user
