# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SumResponse(Model):
    """SumResponse.

    :param sum_meters: Meters in this list will have their use or cost added
     together during the bill calculation
    :type sum_meters: list[~energycap.sdk.models.MeterChild]
    :param sum_meter_groups: Distinct meters from these meter groups will have
     their use or cost added together during the bill calculation
    :type sum_meter_groups: list[~energycap.sdk.models.MeterGroupChild]
    """

    _attribute_map = {
        'sum_meters': {'key': 'sumMeters', 'type': '[MeterChild]'},
        'sum_meter_groups': {'key': 'sumMeterGroups', 'type': '[MeterGroupChild]'},
    }

    def __init__(self, **kwargs):
        super(SumResponse, self).__init__(**kwargs)
        self.sum_meters = kwargs.get('sum_meters', None)
        self.sum_meter_groups = kwargs.get('sum_meter_groups', None)
