# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagIssueTypeChild(Model):
    """FlagIssueTypeChild.

    :param flag_issue_type_id: The flag issue type identifier
    :type flag_issue_type_id: int
    :param flag_issue_type_info: Flag issue info
    :type flag_issue_type_info: str
    :param flag_issue_type_description: More detailed description of the flag
     issue type
    :type flag_issue_type_description: str
    :param flag_issue_category: Flag issue category
    :type flag_issue_category: str
    """

    _attribute_map = {
        'flag_issue_type_id': {'key': 'flagIssueTypeId', 'type': 'int'},
        'flag_issue_type_info': {'key': 'flagIssueTypeInfo', 'type': 'str'},
        'flag_issue_type_description': {'key': 'flagIssueTypeDescription', 'type': 'str'},
        'flag_issue_category': {'key': 'flagIssueCategory', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(FlagIssueTypeChild, self).__init__(**kwargs)
        self.flag_issue_type_id = kwargs.get('flag_issue_type_id', None)
        self.flag_issue_type_info = kwargs.get('flag_issue_type_info', None)
        self.flag_issue_type_description = kwargs.get('flag_issue_type_description', None)
        self.flag_issue_category = kwargs.get('flag_issue_category', None)
