# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportCategoryChild(Model):
    """ReportCategoryChild.

    :param report_category_id:
    :type report_category_id: int
    :param report_category_code:
    :type report_category_code: str
    :param report_category_info:
    :type report_category_info: str
    """

    _attribute_map = {
        'report_category_id': {'key': 'reportCategoryId', 'type': 'int'},
        'report_category_code': {'key': 'reportCategoryCode', 'type': 'str'},
        'report_category_info': {'key': 'reportCategoryInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReportCategoryChild, self).__init__(**kwargs)
        self.report_category_id = kwargs.get('report_category_id', None)
        self.report_category_code = kwargs.get('report_category_code', None)
        self.report_category_info = kwargs.get('report_category_info', None)
